about summary refs log tree commit diff
path: root/sysdeps/x86_64
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/x86_64')
-rw-r--r--sysdeps/x86_64/dl-machine.h4
-rw-r--r--sysdeps/x86_64/x32/dl-machine.h4
2 files changed, 4 insertions, 4 deletions
diff --git a/sysdeps/x86_64/dl-machine.h b/sysdeps/x86_64/dl-machine.h
index f9ee1f79b6..8316f13a06 100644
--- a/sysdeps/x86_64/dl-machine.h
+++ b/sysdeps/x86_64/dl-machine.h
@@ -145,7 +145,7 @@ _dl_start_user:\n\
 	movq %rdx, %rsi\n\
 	# Save %rsp value in %r13.\n\
 	movq %rsp, %r13\n\
 	# And align stack for the _dl_init_internal call. \n\
 	andq $-16, %rsp\n\
 	# _dl_loaded -> rdi\n\
 	movq _rtld_local(%rip), %rdi\n\
@@ -156,7 +156,7 @@ _dl_start_user:\n\
 	# Clear %rbp to mark outermost frame obviously even for constructors.\n\
 	xorl %ebp, %ebp\n\
 	# Call the function to run the initializers.\n\
-	call _dl_init_internal@PLT\n\
+	call _dl_init@PLT\n\
 	# Pass our finalizer function to the user in %rdx, as per ELF ABI.\n\
 	leaq _dl_fini(%rip), %rdx\n\
 	# And make sure %rsp points to argc stored on the stack.\n\
@@ -145,7 +145,7 @@ _dl_start_user:\n\
 	# Save %rsp value in %r13.\n\
 	movq %rsp, %r13\n\
-	# And align stack for the _dl_init_internal call. \n\
+	# And align stack for the _dl_init call. \n\
 	andq $-16, %rsp\n\
 	# _dl_loaded -> rdi\n\
diff --git a/sysdeps/x86_64/x32/dl-machine.h b/sysdeps/x86_64/x32/dl-machine.h
index 3ee41cf4a4..433435e870 100644
--- a/sysdeps/x86_64/x32/dl-machine.h
+++ b/sysdeps/x86_64/x32/dl-machine.h
@@ -62,7 +62,7 @@ _dl_start_user:\n\
 	movl %edx, %esi\n\
 	# Save %rsp value in %r13.\n\
 	movl %esp, %r13d\n\
 	# And align stack for the _dl_init_internal call.\n\
 	and $-16, %esp\n\
 	# _dl_loaded -> rdi\n\
 	movl _rtld_local(%rip), %edi\n\
@@ -73,7 +73,7 @@ _dl_start_user:\n\
 	# Clear %rbp to mark outermost frame obviously even for constructors.\n\
 	xorl %ebp, %ebp\n\
 	# Call the function to run the initializers.\n\
-	call _dl_init_internal\n\
+	call _dl_init\n\
 	# Pass our finalizer function to the user in %rdx, as per ELF ABI.\n\
 	lea _dl_fini(%rip), %edx\n\
 	# And make sure %rsp points to argc stored on the stack.\n\
@@ -62,7 +62,7 @@ _dl_start_user:\n\
 	# Save %rsp value in %r13.\n\
 	movl %esp, %r13d\n\
-	# And align stack for the _dl_init_internal call.\n\
+	# And align stack for the _dl_init call.\n\
 	and $-16, %esp\n\
 	# _dl_loaded -> rdi\n\